@@ -1,6 +1,7 @@
 import ast
 import json
 import logging
+import subprocess
 from threading import Thread
 from time import sleep
 import socketio
@@ -71,13 +72,14 @@ class GSPeerConnectionBroadcasterPiSocket:
         return relay.subscribe(microfon.audio)
 
     @classmethod
-    async def create(cls, sio, gsdbs, camera, oncommand):
+    async def create(cls, sio, gsdbs, camera, oncommand,setChannel=None):
         self = GSPeerConnectionBroadcasterPiSocket()
 
         self.rtconfiList = []
         self._logger = logging.getLogger(__name__)
         self.gsdbs = gsdbs
         self.oncommand = oncommand
+        self.setChannel = setChannel
         # picam.append(camera)
         if self.gsdbs.credentials["stunenable"]:
             self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
@@ -149,14 +151,27 @@ class GSPeerConnectionBroadcasterPiSocket:
             @pc.on("datachannel")
             def on_datachannel(channel):
 
+                self.setChannel(channel)
+
                 channel_log(channel, "-", "created by remote party")
 
+                def subprocess_cmd(command):
+                    process = subprocess.Popen(command, stdout=subprocess.PIPE, shell=True)
+                    proc_stdout = process.communicate()[0].strip()
+                    channel_send(channel, json.dumps({"response": proc_stdout.decode()}))
+
                 @channel.on("message")
                 def on_message(message):
                     channel_log(channel, "<", message)
 
                     if isinstance(message, str) and message.startswith("ping"):
-                        channel_send(channel, f'{{"ping":"pong","ts":"{datetime.utcnow()}"}}' )
+                        # reply
+                        channel_send(channel, f'{{"ping":"pong","ts":"{datetime.utcnow()} UTC"}}')
+                    if isinstance(message, str) and message.startswith('{"type'):
+                        # reply
+                        self.oncommand(self.gsdbs, json.loads(message))
+                    if isinstance(message, str) and message.startswith('{"command'):
+                        subprocess_cmd(json.loads(message)["command"])
 
 
             transceiver = pc.addTransceiver("video", direction="sendonly")
