@@ -124,8 +124,14 @@ class GSPeerConnectionWatcher:
                 desc = type('new_dict', (object,), ast.literal_eval(description))
             await self.peerConnections.setRemoteDescription(desc)
 
+        @self.sio.event
+        async def disconnect(id, target):
+            self.logger.info("Socket connection list")
+            await self.ontrackended(self.gsdbs, target)
+
         @self.sio.event
         async def disconnectBroadcaster(id, target):
+            self.logger.info("Camera connection list")
             await self.ontrackended(self.gsdbs, target)
 
         if "localhost" in self.gsdbs.credentials["signalserver"]:
